
# This file was automatically generated by Dist::Zilla::Plugin::ModuleBuild v6.031.
use strict;
use warnings;

use Module::Build 0.30;


my %module_build_args = (
  "build_requires" => {
    "Module::Build" => "0.4234"
  },
  "configure_requires" => {
    "ExtUtils::MakeMaker" => 0,
    "Module::Build" => "0.4234"
  },
  "dist_abstract" => "Date::Holidays::* adapter and aggregator for all your holiday needs",
  "dist_author" => [
    "Jonas B. <jonasbn\@cpan.org>"
  ],
  "dist_name" => "Date-Holidays",
  "dist_version" => "1.36",
  "license" => "artistic_2",
  "module_name" => "Date::Holidays",
  "recursive_test_files" => 1,
  "requires" => {
    "Carp" => "1.5",
    "DateTime" => "1.59",
    "Env" => "1.04",
    "File::Slurp" => "9999.32",
    "JSON" => "4.1",
    "Locale::Country" => "3.76",
    "Module::Load" => "0.36",
    "Scalar::Util" => "1.63",
    "Try::Tiny" => "0.31",
    "perl" => "5.006"
  },
  "test_requires" => {
    "File::Spec" => 0,
    "FindBin" => "1.53",
    "IO::Handle" => 0,
    "IPC::Open3" => 0,
    "Pod::Coverage::TrustPod" => "0.100006",
    "Test::Class" => "0.52",
    "Test::Fatal" => "0.017",
    "Test::Kwalitee" => "1.28",
    "Test::MockModule" => "0.13",
    "Test::More" => "1.302195",
    "Test::Pod" => "1.52",
    "Test::Pod::Coverage" => "1.1"
  }
);


my %fallback_build_requires = (
  "File::Spec" => 0,
  "FindBin" => "1.53",
  "IO::Handle" => 0,
  "IPC::Open3" => 0,
  "Module::Build" => "0.4234",
  "Pod::Coverage::TrustPod" => "0.100006",
  "Test::Class" => "0.52",
  "Test::Fatal" => "0.017",
  "Test::Kwalitee" => "1.28",
  "Test::MockModule" => "0.13",
  "Test::More" => "1.302195",
  "Test::Pod" => "1.52",
  "Test::Pod::Coverage" => "1.1"
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = Module::Build->new(%module_build_args);


$build->create_build_script;
